params
======

.. automodule:: nwsspc.sharp.calc.params 

   Convective
   ----------
   Convective-based parameters, largely geared towards severe thunderstorms and tornadoes.

   .. autofunction:: nwsspc.sharp.calc.params.effective_inflow_layer
   .. autofunction:: nwsspc.sharp.calc.params.storm_motion_bunkers
   .. autofunction:: nwsspc.sharp.calc.params.mcs_motion_corfidi
   .. autofunction:: nwsspc.sharp.calc.params.effective_bulk_wind_difference
   .. autofunction:: nwsspc.sharp.calc.params.energy_helicity_index
   .. autofunction:: nwsspc.sharp.calc.params.significant_tornado_parameter
   .. autofunction:: nwsspc.sharp.calc.params.supercell_composite_parameter
   .. autofunction:: nwsspc.sharp.calc.params.significant_hail_parameter
   .. autofunction:: nwsspc.sharp.calc.params.derecho_composite_parameter
   .. autofunction:: nwsspc.sharp.calc.params.large_hail_parameter
   .. autofunction:: nwsspc.sharp.calc.params.hail_growth_layer
   .. autofunction:: nwsspc.sharp.calc.params.convective_temperature
   .. autofunction:: nwsspc.sharp.calc.params.precipitable_water

   Fire
   ---- 
   Fire-weather parameters

   .. autofunction:: nwsspc.sharp.calc.params.equilibrium_moisture_content
   .. autofunction:: nwsspc.sharp.calc.params.fosberg_fire_index
   .. autofunction:: nwsspc.sharp.calc.params.pyrocumulonimbus_firepower_threshold

   Winter
   ------
   Winter-weather parameters.

   .. autofunction:: nwsspc.sharp.calc.params.dendritic_layer
   .. autofunction:: nwsspc.sharp.calc.params.snow_squall_parameter
